==> dde-launcher_4.4.5.5.orig.tar.xz: dde-launcher-4.4.5.5/translations/dde-launcher_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Žádné výsledky hledání</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Opravdu chcete odinstalovat %1?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdit</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Odstranit z plochy</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Odebrat z panelu</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Odinstalovat</translation>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation>Otevřít v zastoupení</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Zakázat měřítko zobrazení</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Odeslat na plochu</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Odeslat do panelu</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Odstranit ze spuštění</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Přidat do spuštění</translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Všechny programy</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Obraz</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafika</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Hra</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Kancelář</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Čtení</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Vývoj</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Systém</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Jiné</translation>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Opravdu chcete odinstalovat %1?</translation>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation>Všechny závislosti budou odstraněny společně</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdit</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Počítač</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Obrazy</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Stahování</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Uzamknout</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Odhlásit</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Restartovat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uspat</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Vypnout</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Počítač</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Vypnout</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Uzamknout</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Odhlásit</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Restartovat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uspat</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Obrazy</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Stahování</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Počítač</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Stahování</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ruční</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Vypnout</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Obrazy</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Opravdu chcete odinstalovat %1?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdit</translation>
    </message>
</context>
</TS>

==> dde-launcher_4.6.13.orig.tar.xz: dde-launcher-4.6.13/translations/dde-launcher_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Žádné výsledky hledání</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Obraz</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafika</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Kancelář</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Čtení</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Vývoj</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Systém</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Hry</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Jiné</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdit</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Odstranit z plochy</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Odebrat z panelu</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Odinstalovat</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Zakázat měřítko zobrazení</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Odeslat na plochu</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Odeslat do panelu</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Odstranit ze spuštění</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Přidat do spuštění</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Všechny programy</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Rozhovor</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Obraz</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafika</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Hra</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Kancelář</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Čtení</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Vývoj</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Systém</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Jiné</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Počítač</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Obrazy</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Stahování</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Uzamknout</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Odhlásit</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Restartovat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uspat</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Vypnout</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Počítač</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Vypnout</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Uzamknout</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Odhlásit</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Restartovat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uspat</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Obrazy</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Stahování</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Počítač</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Stahování</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ruční</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Obrazy</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Napájení</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Všechny kategorie</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdit</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
